==> haskell-cryptohash-conduit-0.1.1-88-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-3NRP2trasnS6k6hHJNNTWR
key: cryptohash-conduit-0.1.1-3NRP2trasnS6k6hHJNNTWR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: 80a679af345850e3b3fe8ced7af594d3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-3NRP2trasnS6k6hHJNNTWR
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    conduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW
    conduit-extra-1.1.16-C3xWe88KfHvD9kiG2dJ0pk
    cryptohash-0.11.9-4MoiP4rhlbnADtveb6D3wO
    resourcet-1.1.9-8dcH1R5asu46j8AjnoNKK5 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-90-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-EMyPCCYpMiU9Dblpi16oI3
key: cryptohash-conduit-0.1.1-EMyPCCYpMiU9Dblpi16oI3
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: 42aab0c1efdcc41ed8f8bb8431430636
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-EMyPCCYpMiU9Dblpi16oI3
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    conduit-extra-1.1.16-D6NCchbcP4B5d2Ej6lg3Np
    cryptohash-0.11.9-4MoiP4rhlbnADtveb6D3wO
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
